# JKS measurement database system
[![DOI](https://zenodo.org/badge/881044249.svg)](https://doi.org/10.5281/zenodo.14017592)

Install using

> python3 -m pip install jks-system

# Citation
You can cite usage of the system as
```
@software{christoph_lehner_2024_14017593,
  author       = {Christoph Lehner},
  title        = {{JKS measurement database, 2024-10}},
  month        = 10,
  year         = 2024,
  publisher    = {Zenodo},
  version      = {2024-10},
  doi          = {10.5281/zenodo.14017593},
  url          = {https://doi.org/10.5281/zenodo.14017593}
}
```
